crypto

Home Download News Documentation FAQ Tutorial API reference Examples XML Digital Signature Online Verifier XML Encryption XML Canonicalization Reporting Bugs Mailing list Related Authors
# crypto ## Name crypto -- Crypto transforms implementation for GnuTLS. ## Synopsis
    xmlSecCryptoDLFunctionsPtr  xmlSecCryptoGetFunctions_gnutls
                                                            (void);
    int                 xmlSecGnuTLSInit                    (void);
    int                 xmlSecGnuTLSShutdown                (void);
    int                 xmlSecGnuTLSKeysMngrInit            (xmlSecKeysMngrPtr mngr);
    int                 xmlSecGnuTLSGenerateRandom          (xmlSecBufferPtr buffer,
                                                             xmlSecSize size);
    #define             xmlSecGnuTLSKeyDataAesId
    xmlSecKeyDataId     xmlSecGnuTLSKeyDataAesGetKlass      (void);
    int                 xmlSecGnuTLSKeyDataAesSet           (xmlSecKeyDataPtr data,
                                                             const xmlSecByte *buf,
                                                             xmlSecSize bufSize);
    #define             xmlSecGnuTLSTransformAes128CbcId
    xmlSecTransformId   xmlSecGnuTLSTransformAes128CbcGetKlass
                                                            (void);
    #define             xmlSecGnuTLSTransformAes192CbcId
    xmlSecTransformId   xmlSecGnuTLSTransformAes192CbcGetKlass
                                                            (void);
    #define             xmlSecGnuTLSTransformAes256CbcId
    xmlSecTransformId   xmlSecGnuTLSTransformAes256CbcGetKlass
                                                            (void);
    #define             xmlSecGnuTLSTransformKWAes128Id
    xmlSecTransformId   xmlSecGnuTLSTransformKWAes128GetKlass
                                                            (void);
    #define             xmlSecGnuTLSTransformKWAes192Id
    xmlSecTransformId   xmlSecGnuTLSTransformKWAes192GetKlass
                                                            (void);
    #define             xmlSecGnuTLSTransformKWAes256Id
    xmlSecTransformId   xmlSecGnuTLSTransformKWAes256GetKlass
                                                            (void);
    #define             xmlSecGnuTLSKeyDataDesId
    xmlSecKeyDataId     xmlSecGnuTLSKeyDataDesGetKlass      (void);
    int                 xmlSecGnuTLSKeyDataDesSet           (xmlSecKeyDataPtr data,
                                                             const xmlSecByte *buf,
                                                             xmlSecSize bufSize);
    #define             xmlSecGnuTLSTransformDes3CbcId
    xmlSecTransformId   xmlSecGnuTLSTransformDes3CbcGetKlass
                                                            (void);
    #define             xmlSecGnuTLSTransformKWDes3Id
    xmlSecTransformId   xmlSecGnuTLSTransformKWDes3GetKlass (void);
    #define             xmlSecGnuTLSKeyDataDsaId
    xmlSecKeyDataId     xmlSecGnuTLSKeyDataDsaGetKlass      (void);
    int                 xmlSecGnuTLSKeyDataDsaAdoptPrivateKey
                                                            (xmlSecKeyDataPtr data,
                                                             gnutls_x509_privkey_t dsa_key);
    int                 xmlSecGnuTLSKeyDataDsaAdoptPublicKey
                                                            (xmlSecKeyDataPtr data,
                                                             gnutls_datum_t *p,
                                                             gnutls_datum_t *q,
                                                             gnutls_datum_t *g,
                                                             gnutls_datum_t *y);
    #define             xmlSecGnuTLSTransformDsaSha1Id
    xmlSecTransformId   xmlSecGnuTLSTransformDsaSha1GetKlass
                                                            (void);
    int                 xmlSecGnuTLSHmacGetMinOutputLength  (void);
    void                xmlSecGnuTLSHmacSetMinOutputLength  (int min_length);
    #define             xmlSecGnuTLSKeyDataHmacId
    xmlSecKeyDataId     xmlSecGnuTLSKeyDataHmacGetKlass     (void);
    int                 xmlSecGnuTLSKeyDataHmacSet          (xmlSecKeyDataPtr data,
                                                             const xmlSecByte *buf,
                                                             xmlSecSize bufSize);
    #define             xmlSecGnuTLSTransformHmacMd5Id
    xmlSecTransformId   xmlSecGnuTLSTransformHmacMd5GetKlass
                                                            (void);
    #define             xmlSecGnuTLSTransformHmacRipemd160Id
    xmlSecTransformId   xmlSecGnuTLSTransformHmacRipemd160GetKlass
                                                            (void);
    #define             xmlSecGnuTLSTransformHmacSha1Id
    xmlSecTransformId   xmlSecGnuTLSTransformHmacSha1GetKlass
                                                            (void);
    #define             xmlSecGnuTLSTransformHmacSha256Id
    xmlSecTransformId   xmlSecGnuTLSTransformHmacSha256GetKlass
                                                            (void);
    #define             xmlSecGnuTLSTransformHmacSha384Id
    xmlSecTransformId   xmlSecGnuTLSTransformHmacSha384GetKlass
                                                            (void);
    #define             xmlSecGnuTLSTransformHmacSha512Id
    xmlSecTransformId   xmlSecGnuTLSTransformHmacSha512GetKlass
                                                            (void);
    #define             xmlSecGnuTLSKeyDataRsaId
    xmlSecKeyDataId     xmlSecGnuTLSKeyDataRsaGetKlass      (void);
    int                 xmlSecGnuTLSKeyDataRsaAdoptPrivateKey
                                                            (xmlSecKeyDataPtr data,
                                                             gnutls_x509_privkey_t rsa_key);
    int                 xmlSecGnuTLSKeyDataRsaAdoptPublicKey
                                                            (xmlSecKeyDataPtr data,
                                                             gnutls_datum_t *m,
                                                             gnutls_datum_t *e);
    #define             xmlSecGnuTLSTransformRsaMd5Id
    xmlSecTransformId   xmlSecGnuTLSTransformRsaMd5GetKlass (void);
    #define             xmlSecGnuTLSTransformRsaRipemd160Id
    xmlSecTransformId   xmlSecGnuTLSTransformRsaRipemd160GetKlass
                                                            (void);
    #define             xmlSecGnuTLSTransformRsaSha1Id
    xmlSecTransformId   xmlSecGnuTLSTransformRsaSha1GetKlass
                                                            (void);
    #define             xmlSecGnuTLSTransformRsaSha256Id
    xmlSecTransformId   xmlSecGnuTLSTransformRsaSha256GetKlass
                                                            (void);
    #define             xmlSecGnuTLSTransformRsaSha384Id
    xmlSecTransformId   xmlSecGnuTLSTransformRsaSha384GetKlass
                                                            (void);
    #define             xmlSecGnuTLSTransformRsaSha512Id
    xmlSecTransformId   xmlSecGnuTLSTransformRsaSha512GetKlass
                                                            (void);
    #define             xmlSecGnuTLSTransformSha1Id
    xmlSecTransformId   xmlSecGnuTLSTransformSha1GetKlass   (void);
    #define             xmlSecGnuTLSTransformSha256Id
    xmlSecTransformId   xmlSecGnuTLSTransformSha256GetKlass (void);
    #define             xmlSecGnuTLSTransformSha384Id
    xmlSecTransformId   xmlSecGnuTLSTransformSha384GetKlass (void);
    #define             xmlSecGnuTLSTransformSha512Id
    xmlSecTransformId   xmlSecGnuTLSTransformSha512GetKlass (void);
    #define             xmlSecGnuTLSTransformMd5Id
    xmlSecTransformId   xmlSecGnuTLSTransformMd5GetKlass    (void);
    #define             xmlSecGnuTLSTransformRipemd160Id
    xmlSecTransformId   xmlSecGnuTLSTransformRipemd160GetKlass
                                                            (void);
## Description Crypto transforms implementation for GnuTLS. ## Details ### xmlSecCryptoGetFunctions_gnutls ()
    xmlSecCryptoDLFunctionsPtr  xmlSecCryptoGetFunctions_gnutls
                                                            (void);
Gets the pointer to xmlsec-gnutls functions table.
Returns : | the xmlsec-gnutls functions table or NULL if an error occurs.
### xmlSecGnuTLSInit ()
    int                 xmlSecGnuTLSInit                    (void);
XMLSec library specific crypto engine initialization.
Returns : | 0 on success or a negative value otherwise.
### xmlSecGnuTLSShutdown ()
    int                 xmlSecGnuTLSShutdown                (void);
XMLSec library specific crypto engine shutdown.
Returns : | 0 on success or a negative value otherwise.
### xmlSecGnuTLSKeysMngrInit ()
    int                 xmlSecGnuTLSKeysMngrInit            (xmlSecKeysMngrPtr mngr);
Adds GnuTLS specific key data stores in keys manager.
`mngr` : | the pointer to keys manager.
Returns : | 0 on success or a negative value otherwise.
### xmlSecGnuTLSGenerateRandom ()
    int                 xmlSecGnuTLSGenerateRandom          (xmlSecBufferPtr buffer,
                                                             xmlSecSize size);
Generates `size` random bytes and puts result in `buffer`.
`buffer` : | the destination buffer.
`size` : | the numer of bytes to generate.
Returns : | 0 on success or a negative value otherwise.
### xmlSecGnuTLSKeyDataAesId
    #define             xmlSecGnuTLSKeyDataAesId
The AES key data klass. ### xmlSecGnuTLSKeyDataAesGetKlass ()
    xmlSecKeyDataId     xmlSecGnuTLSKeyDataAesGetKlass      (void);
The AES key data klass.
Returns : | AES key data klass.
### xmlSecGnuTLSKeyDataAesSet ()
    int                 xmlSecGnuTLSKeyDataAesSet           (xmlSecKeyDataPtr data,
                                                             const xmlSecByte *buf,
                                                             xmlSecSize bufSize);
Sets the value of AES key data.
`data` : | the pointer to AES key data.
`buf` : | the pointer to key value.
`bufSize` : | the key value size (in bytes).
Returns : | 0 on success or a negative value if an error occurs.
### xmlSecGnuTLSTransformAes128CbcId
    #define             xmlSecGnuTLSTransformAes128CbcId
The AES128 CBC cipher transform klass. ### xmlSecGnuTLSTransformAes128CbcGetKlass ()
    xmlSecTransformId   xmlSecGnuTLSTransformAes128CbcGetKlass
                                                            (void);
AES 128 CBC encryption transform klass.
Returns : | pointer to AES 128 CBC encryption transform.
### xmlSecGnuTLSTransformAes192CbcId
    #define             xmlSecGnuTLSTransformAes192CbcId
The AES192 CBC cipher transform klass. ### xmlSecGnuTLSTransformAes192CbcGetKlass ()
    xmlSecTransformId   xmlSecGnuTLSTransformAes192CbcGetKlass
                                                            (void);
AES 192 CBC encryption transform klass.
Returns : | pointer to AES 192 CBC encryption transform.
### xmlSecGnuTLSTransformAes256CbcId
    #define             xmlSecGnuTLSTransformAes256CbcId
The AES256 CBC cipher transform klass. ### xmlSecGnuTLSTransformAes256CbcGetKlass ()
    xmlSecTransformId   xmlSecGnuTLSTransformAes256CbcGetKlass
                                                            (void);
AES 256 CBC encryption transform klass.
Returns : | pointer to AES 256 CBC encryption transform.
### xmlSecGnuTLSTransformKWAes128Id
    #define             xmlSecGnuTLSTransformKWAes128Id
The AES 128 key wrap transform klass. ### xmlSecGnuTLSTransformKWAes128GetKlass ()
    xmlSecTransformId   xmlSecGnuTLSTransformKWAes128GetKlass
                                                            (void);
The AES-128 kew wrapper transform klass.
Returns : | AES-128 kew wrapper transform klass.
### xmlSecGnuTLSTransformKWAes192Id
    #define             xmlSecGnuTLSTransformKWAes192Id
The AES 192 key wrap transform klass. ### xmlSecGnuTLSTransformKWAes192GetKlass ()
    xmlSecTransformId   xmlSecGnuTLSTransformKWAes192GetKlass
                                                            (void);
The AES-192 kew wrapper transform klass.
Returns : | AES-192 kew wrapper transform klass.
### xmlSecGnuTLSTransformKWAes256Id
    #define             xmlSecGnuTLSTransformKWAes256Id
The AES 256 key wrap transform klass. ### xmlSecGnuTLSTransformKWAes256GetKlass ()
    xmlSecTransformId   xmlSecGnuTLSTransformKWAes256GetKlass
                                                            (void);
The AES-256 kew wrapper transform klass.
Returns : | AES-256 kew wrapper transform klass.
### xmlSecGnuTLSKeyDataDesId
    #define             xmlSecGnuTLSKeyDataDesId
The DES key data klass. ### xmlSecGnuTLSKeyDataDesGetKlass ()
    xmlSecKeyDataId     xmlSecGnuTLSKeyDataDesGetKlass      (void);
The DES key data klass.
Returns : | DES key data klass.
### xmlSecGnuTLSKeyDataDesSet ()
    int                 xmlSecGnuTLSKeyDataDesSet           (xmlSecKeyDataPtr data,
                                                             const xmlSecByte *buf,
                                                             xmlSecSize bufSize);
Sets the value of DES key data.
`data` : | the pointer to DES key data.
`buf` : | the pointer to key value.
`bufSize` : | the key value size (in bytes).
Returns : | 0 on success or a negative value if an error occurs.
### xmlSecGnuTLSTransformDes3CbcId
    #define             xmlSecGnuTLSTransformDes3CbcId
The DES3 CBC cipher transform klass. ### xmlSecGnuTLSTransformDes3CbcGetKlass ()
    xmlSecTransformId   xmlSecGnuTLSTransformDes3CbcGetKlass
                                                            (void);
Triple DES CBC encryption transform klass.
Returns : | pointer to Triple DES encryption transform.
### xmlSecGnuTLSTransformKWDes3Id
    #define             xmlSecGnuTLSTransformKWDes3Id
The DES3 KW transform klass. ### xmlSecGnuTLSTransformKWDes3GetKlass ()
    xmlSecTransformId   xmlSecGnuTLSTransformKWDes3GetKlass (void);
The Triple DES key wrapper transform klass.
Returns : | Triple DES key wrapper transform klass.
### xmlSecGnuTLSKeyDataDsaId
    #define             xmlSecGnuTLSKeyDataDsaId
The DSA key klass. ### xmlSecGnuTLSKeyDataDsaGetKlass ()
    xmlSecKeyDataId     xmlSecGnuTLSKeyDataDsaGetKlass      (void);
The DSA key data klass.
Returns : | pointer to DSA key data klass.
### xmlSecGnuTLSKeyDataDsaAdoptPrivateKey ()
    int                 xmlSecGnuTLSKeyDataDsaAdoptPrivateKey
                                                            (xmlSecKeyDataPtr data,
                                                             gnutls_x509_privkey_t dsa_key);
Sets the value of DSA key data.
`data` : | the pointer to DSA key data.
`dsa_key` : | the pointer to GnuTLS DSA private key.
Returns : | 0 on success or a negative value otherwise.
### xmlSecGnuTLSKeyDataDsaAdoptPublicKey ()
    int                 xmlSecGnuTLSKeyDataDsaAdoptPublicKey
                                                            (xmlSecKeyDataPtr data,
                                                             gnutls_datum_t *p,
                                                             gnutls_datum_t *q,
                                                             gnutls_datum_t *g,
                                                             gnutls_datum_t *y);
Sets the value of DSA key data.
`data` : | the pointer to DSA key data.
`p` : | the pointer to p component of the DSA public key
`q` : | the pointer to q component of the DSA public key
`g` : | the pointer to g component of the DSA public key
`y` : | the pointer to y component of the DSA public key
Returns : | 0 on success or a negative value otherwise.
### xmlSecGnuTLSTransformDsaSha1Id
    #define             xmlSecGnuTLSTransformDsaSha1Id
The DSA SHA1 signature transform klass. ### xmlSecGnuTLSTransformDsaSha1GetKlass ()
    xmlSecTransformId   xmlSecGnuTLSTransformDsaSha1GetKlass
                                                            (void);
The DSA-SHA1 signature transform klass.
Returns : | DSA-SHA1 signature transform klass.
### xmlSecGnuTLSHmacGetMinOutputLength ()
    int                 xmlSecGnuTLSHmacGetMinOutputLength  (void);
Gets the value of min HMAC length.
Returns : | the min HMAC output length
### xmlSecGnuTLSHmacSetMinOutputLength ()
    void                xmlSecGnuTLSHmacSetMinOutputLength  (int min_length);
Sets the min HMAC output length
`min_length` : | the new min length
### xmlSecGnuTLSKeyDataHmacId
    #define             xmlSecGnuTLSKeyDataHmacId
The HMAC key klass. ### xmlSecGnuTLSKeyDataHmacGetKlass ()
    xmlSecKeyDataId     xmlSecGnuTLSKeyDataHmacGetKlass     (void);
The HMAC key data klass.
Returns : | HMAC key data klass.
### xmlSecGnuTLSKeyDataHmacSet ()
    int                 xmlSecGnuTLSKeyDataHmacSet          (xmlSecKeyDataPtr data,
                                                             const xmlSecByte *buf,
                                                             xmlSecSize bufSize);
Sets the value of HMAC key data.
`data` : | the pointer to HMAC key data.
`buf` : | the pointer to key value.
`bufSize` : | the key value size (in bytes).
Returns : | 0 on success or a negative value if an error occurs.
### xmlSecGnuTLSTransformHmacMd5Id
    #define             xmlSecGnuTLSTransformHmacMd5Id
The HMAC with MD5 signature transform klass. ### xmlSecGnuTLSTransformHmacMd5GetKlass ()
    xmlSecTransformId   xmlSecGnuTLSTransformHmacMd5GetKlass
                                                            (void);
The HMAC-MD5 transform klass.
Returns : | the HMAC-MD5 transform klass.
### xmlSecGnuTLSTransformHmacRipemd160Id
    #define             xmlSecGnuTLSTransformHmacRipemd160Id
The HMAC with RipeMD160 signature transform klass. ### xmlSecGnuTLSTransformHmacRipemd160GetKlass ()
    xmlSecTransformId   xmlSecGnuTLSTransformHmacRipemd160GetKlass
                                                            (void);
The HMAC-RIPEMD160 transform klass.
Returns : | the HMAC-RIPEMD160 transform klass.
### xmlSecGnuTLSTransformHmacSha1Id
    #define             xmlSecGnuTLSTransformHmacSha1Id
The HMAC with SHA1 signature transform klass. ### xmlSecGnuTLSTransformHmacSha1GetKlass ()
    xmlSecTransformId   xmlSecGnuTLSTransformHmacSha1GetKlass
                                                            (void);
The HMAC-SHA1 transform klass.
Returns : | the HMAC-SHA1 transform klass.
### xmlSecGnuTLSTransformHmacSha256Id
    #define             xmlSecGnuTLSTransformHmacSha256Id
The HMAC with SHA256 signature transform klass. ### xmlSecGnuTLSTransformHmacSha256GetKlass ()
    xmlSecTransformId   xmlSecGnuTLSTransformHmacSha256GetKlass
                                                            (void);
The HMAC-SHA256 transform klass.
Returns : | the HMAC-SHA256 transform klass.
### xmlSecGnuTLSTransformHmacSha384Id
    #define             xmlSecGnuTLSTransformHmacSha384Id
The HMAC with SHA384 signature transform klass. ### xmlSecGnuTLSTransformHmacSha384GetKlass ()
    xmlSecTransformId   xmlSecGnuTLSTransformHmacSha384GetKlass
                                                            (void);
The HMAC-SHA384 transform klass.
Returns : | the HMAC-SHA384 transform klass.
### xmlSecGnuTLSTransformHmacSha512Id
    #define             xmlSecGnuTLSTransformHmacSha512Id
The HMAC with SHA512 signature transform klass. ### xmlSecGnuTLSTransformHmacSha512GetKlass ()
    xmlSecTransformId   xmlSecGnuTLSTransformHmacSha512GetKlass
                                                            (void);
The HMAC-SHA512 transform klass.
Returns : | the HMAC-SHA512 transform klass.
### xmlSecGnuTLSKeyDataRsaId
    #define             xmlSecGnuTLSKeyDataRsaId
The RSA key klass. ### xmlSecGnuTLSKeyDataRsaGetKlass ()
    xmlSecKeyDataId     xmlSecGnuTLSKeyDataRsaGetKlass      (void);
The GnuTLS RSA key data klass.
Returns : | pointer to GnuTLS RSA key data klass.
### xmlSecGnuTLSKeyDataRsaAdoptPrivateKey ()
    int                 xmlSecGnuTLSKeyDataRsaAdoptPrivateKey
                                                            (xmlSecKeyDataPtr data,
                                                             gnutls_x509_privkey_t rsa_key);
Sets the value of RSA key data.
`data` : | the pointer to RSA key data.
`rsa_key` : | the pointer to GnuTLS RSA private key.
Returns : | 0 on success or a negative value otherwise.
### xmlSecGnuTLSKeyDataRsaAdoptPublicKey ()
    int                 xmlSecGnuTLSKeyDataRsaAdoptPublicKey
                                                            (xmlSecKeyDataPtr data,
                                                             gnutls_datum_t *m,
                                                             gnutls_datum_t *e);
Sets the value of RSA key data.
`data` : | the pointer to RSA key data.
`m` : | the pointer to m component of the RSA public key
`e` : | the pointer to e component of the RSA public key
Returns : | 0 on success or a negative value otherwise.
### xmlSecGnuTLSTransformRsaMd5Id
    #define             xmlSecGnuTLSTransformRsaMd5Id
The RSA-MD5 signature transform klass. ### xmlSecGnuTLSTransformRsaMd5GetKlass ()
    xmlSecTransformId   xmlSecGnuTLSTransformRsaMd5GetKlass (void);
The RSA-MD5 signature transform klass.
Returns : | RSA-MD5 signature transform klass.
### xmlSecGnuTLSTransformRsaRipemd160Id
    #define             xmlSecGnuTLSTransformRsaRipemd160Id
The RSA-RIPEMD160 signature transform klass. ### xmlSecGnuTLSTransformRsaRipemd160GetKlass ()
    xmlSecTransformId   xmlSecGnuTLSTransformRsaRipemd160GetKlass
                                                            (void);
The RSA-RIPEMD160 signature transform klass.
Returns : | RSA-RIPEMD160 signature transform klass.
### xmlSecGnuTLSTransformRsaSha1Id
    #define             xmlSecGnuTLSTransformRsaSha1Id
The RSA-SHA1 signature transform klass. ### xmlSecGnuTLSTransformRsaSha1GetKlass ()
    xmlSecTransformId   xmlSecGnuTLSTransformRsaSha1GetKlass
                                                            (void);
The RSA-SHA1 signature transform klass.
Returns : | RSA-SHA1 signature transform klass.
### xmlSecGnuTLSTransformRsaSha256Id
    #define             xmlSecGnuTLSTransformRsaSha256Id
The RSA-SHA256 signature transform klass. ### xmlSecGnuTLSTransformRsaSha256GetKlass ()
    xmlSecTransformId   xmlSecGnuTLSTransformRsaSha256GetKlass
                                                            (void);
The RSA-SHA256 signature transform klass.
Returns : | RSA-SHA256 signature transform klass.
### xmlSecGnuTLSTransformRsaSha384Id
    #define             xmlSecGnuTLSTransformRsaSha384Id
The RSA-SHA384 signature transform klass. ### xmlSecGnuTLSTransformRsaSha384GetKlass ()
    xmlSecTransformId   xmlSecGnuTLSTransformRsaSha384GetKlass
                                                            (void);
The RSA-SHA384 signature transform klass.
Returns : | RSA-SHA384 signature transform klass.
### xmlSecGnuTLSTransformRsaSha512Id
    #define             xmlSecGnuTLSTransformRsaSha512Id
The RSA-SHA512 signature transform klass. ### xmlSecGnuTLSTransformRsaSha512GetKlass ()
    xmlSecTransformId   xmlSecGnuTLSTransformRsaSha512GetKlass
                                                            (void);
The RSA-SHA512 signature transform klass.
Returns : | RSA-SHA512 signature transform klass.
### xmlSecGnuTLSTransformSha1Id
    #define             xmlSecGnuTLSTransformSha1Id
The HMAC with SHA1 signature transform klass. ### xmlSecGnuTLSTransformSha1GetKlass ()
    xmlSecTransformId   xmlSecGnuTLSTransformSha1GetKlass   (void);
SHA-1 digest transform klass.
Returns : | pointer to SHA-1 digest transform klass.
### xmlSecGnuTLSTransformSha256Id
    #define             xmlSecGnuTLSTransformSha256Id
The HMAC with SHA256 signature transform klass. ### xmlSecGnuTLSTransformSha256GetKlass ()
    xmlSecTransformId   xmlSecGnuTLSTransformSha256GetKlass (void);
SHA256 digest transform klass.
Returns : | pointer to SHA256 digest transform klass.
### xmlSecGnuTLSTransformSha384Id
    #define             xmlSecGnuTLSTransformSha384Id
The HMAC with SHA384 signature transform klass. ### xmlSecGnuTLSTransformSha384GetKlass ()
    xmlSecTransformId   xmlSecGnuTLSTransformSha384GetKlass (void);
SHA384 digest transform klass.
Returns : | pointer to SHA384 digest transform klass.
### xmlSecGnuTLSTransformSha512Id
    #define             xmlSecGnuTLSTransformSha512Id
The HMAC with SHA512 signature transform klass. ### xmlSecGnuTLSTransformSha512GetKlass ()
    xmlSecTransformId   xmlSecGnuTLSTransformSha512GetKlass (void);
SHA512 digest transform klass.
Returns : | pointer to SHA512 digest transform klass.
### xmlSecGnuTLSTransformMd5Id
    #define             xmlSecGnuTLSTransformMd5Id
The MD5 digest transform klass. ### xmlSecGnuTLSTransformMd5GetKlass ()
    xmlSecTransformId   xmlSecGnuTLSTransformMd5GetKlass    (void);
MD5 digest transform klass.
Returns : | pointer to MD5 digest transform klass.
### xmlSecGnuTLSTransformRipemd160Id
    #define             xmlSecGnuTLSTransformRipemd160Id
The RIPEMD160 digest transform klass. ### xmlSecGnuTLSTransformRipemd160GetKlass ()
    xmlSecTransformId   xmlSecGnuTLSTransformRipemd160GetKlass
                                                            (void);
RIPEMD160 digest transform klass.
Returns : | pointer to RIPEMD160 digest transform klass.